@@ -344,7 +344,7 @@ my_friendly_abort (i)
 	  else
 	    ack ("Internal compiler error %d.", i);
 	  ack ("Please submit a full bug report.");
-	  ack ("See <URL:http://gcc.gnu.org/faq.html#bugreport> for instructions.");
+	  ack ("See <URL:http://www.gnu.org/software/gcc/faq.html#bugreport> for instructions.");
 	}
       else
 	error ("confused by earlier errors, bailing out");
@@ -359,7 +359,7 @@ my_friendly_abort (i)
     error ("Internal compiler error %d.", i);
 
   error ("Please submit a full bug report.");
-  fatal ("See <URL:http://egcs.cygnus.com/faq.html#bugreport> for instructions.");
+  fatal ("See <URL:http://www.gnu.org/software/gcc/faq.html#bugreport> for instructions.");
 }
 
 void
